Skip to contents

Returns information about the range of school years for which enrollment data is available from the New Mexico Public Education Department.

Usage

get_available_years()

Value

A list with three elements:

min_year

The earliest available school year end (e.g., 2016 = 2015-16)

max_year

The most recent available school year end (e.g., 2025 = 2024-25)

description

A human-readable description of data availability

Examples

years <- get_available_years()
years$min_year
#> [1] 2016
years$max_year
#> [1] 2026